@@ -1,26 +1,18 @@
 from pyga.requests import Tracker, Visitor, Session, Page
-
+from flask import request
 
 class MxitGA(object):
 	def __init__(self, app=None):
 		self.app = app
-		if app is not None:
-			self.init_app(app)
 		tracking_id = app.config['GA']['ID']
 		domain = app.config['GA']['DOMAIN']
 		self.tracker = Tracker(tracking_id, domain)
 
-	def init_app(self, app):
-		if hasattr(app, 'teardown_appcontext'):
-			app.teardown_appcontext(self.teardown)
-		else:
-			app.teardown_request(self.teardown)
-
-	def connect(self):
-		pass
-
-	def teardown(self, exception):
-		pass
+	def register_blueprint(self, blueprint):
+		def f(response):
+			self.track(request)
+			return response
+		blueprint.after_request(f)
 
 	def track(self, request):
 		if 'X-Forwarded-For' not in request.headers:
@@ -33,6 +25,5 @@ class MxitGA(object):
 			session = Session()
 			page = Page(request.path)
 			self.tracker.track_pageview(page, session, visitor)
-			print('Tracked page')
 		except Exception as e:
 			print('Problem tracking event: %s\nProblem:\n%s' % (str(request), e))
\ No newline at end of file
